==> calendar-v1.7.20.zip: calendar/messages/de/base.php <==
<?php

return [
    '<strong>Add</strong> profile calendar' => 'Profilkalender <strong>erstellen</strong>',
    '<strong>Choose</strong> target calendar' => 'Zielkalender <strong>wählen</strong>',
    '<strong>Reminder</strong> settings' => '<strong>Erinnerungs</strong>einstellungen',
    'Add all Space members with status {status}' => 'Alle Space-Mitglieder hinzufügen und als {status} markieren',
    'Add participants...' => 'Teilnehmer hinzufügen und markieren als ...',
    'Added: {users}' => 'Hinzugefügt: {users}',
    'Additional Information for participants' => 'Weitere Teilnahme-Infos',
    'Adds a calendar for private or public events to your profile and main menu.' => 'Fügt deinem Profil und Hauptmenü einen Kalender für private und öffentliche Termine hinzu.',
    'Adds an event calendar to this space.' => 'Fügt diesem Space einen Kalender hinzu.',
    'After (occurrences)' => 'Nach (Anzahl)',
    'All Day' => 'Ganztägig',
    'Allow option \'Decline\'' => 'Erlaube Option "Ablehnen"',
    'Allow option \'Undecided\'' => 'Erlaube Option "Vielleicht"',
    'Allows the user to create new calendar entries' => 'Erlaubt dem Benutzer, neue Kalendereinträge zu erstellen.',
    'Allows the user to edit/delete existing calendar entries' => 'Erlaubt dem Benutzer, bestehende Kalendereinträge zu bearbeiten/löschen.',
    'Attending' => 'Du nimmst teil',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => 'Bevor ein Zielkalender ausgewählt werden kann, muss das Modul in mindestens einem Space aktiviert sein.',
    'Birthday' => 'Geburtstag',
    'CalDAV' => 'CalDAV',
    'Calendar' => 'Kalender',
    'Calendar event' => 'Kalender Termin',
    'Calendar events' => 'Kalender Termine',
    'Cancel Event' => 'Termin absagen',
    'Cannot remove the participant!' => 'Teilnehmer konnte nicht entfernt werden!',
    'Create entry' => 'Kalendereinträge erstellen',
    'Custom reminder' => 'Individuelle Erinnerung',
    'Day' => 'Tag',
    'Days' => 'Tage',
    'Default reminder settings' => 'Standardmäßige Einstellungen',
    'Delete all events' => 'Alle Termine löschen',
    'Deleted' => 'Gelöscht',
    'Description' => 'Beschreibung',
    'Display events within the next X days' => 'Zeige die Termine innerhalb der nächsten X Tage',
    'Do you want to install this module on your profile?' => 'Willst du dieses Modul für dein eigenes Profil installieren?',
    'Download ICS' => 'Herunterladen als ICS-Datei',
    'Edit' => 'Bearbeiten',
    'Edit Event' => 'Termin bearbeiten',
    'Edit all events' => 'Alle Termine bearbeiten',
    'Edit this and following events' => 'Diesen und alle folgenden Termine bearbeiten',
    'Edit this event' => 'Diesen Termin ändern',
    'Email' => 'E-Mail-Adresse',
    'Enable' => 'Aktivieren',
    'Enable Reminder' => 'Erinnerung einrichten',
    'End' => 'Ende',
    'End Date' => 'Enddatum',
    'End Time' => 'Endzeit',
    'End time must be after start time!' => 'Die Endzeit muss nach der Startzeit sein!',
    'Event' => 'Termin',
    'Event Type' => 'Event Kategorie',
    'Event Types' => 'Event Kategorien',
    'Event could not be deleted!' => 'Veranstaltung konnte nicht gelöscht werden!',
    'Event has been be deleted!' => 'Veranstaltung wurde gelöscht!',
    'Event not found!' => 'Termin nicht gefunden!',
    'Export as {type}' => 'Exportiere als {type}',
    'Files' => 'Dateien',
    'Filter by types' => 'Filtern nach Kategorie',
    'Friday' => 'Freitag',
    'From Newest to Oldest' => 'Vom Neuesten zum Ältesten',
    'From Oldest to Newest' => 'Vom Ältesten zum Neuesten',
    'Here you can configure default settings for all calendar events.' => 'Hier können Sie Voreinstellungen für alle Kalendereinträge definieren.',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => 'Hier können Sie globale Voreinstellungen für die Erinnerungsfunktion definieren. Diese Einstellungen können von individuellen Einstellungen innerhalb der Spaces oder Profile überschrieben werden.',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
        <strong>Set reminder</strong> link.' => 'Hier können Sie Voreinstellungen für einzelne Termine definieren. Benutzer können diese für sich persönlich und individuell anpassen.',
    'Hour' => 'Stunde',
    'I\'m attending' => 'Ich nehme teil',
    'ID' => 'ID',
    'In order to add events to your profile, you have to enable the calendar module first.' => 'Um deinem Profil Termine hinzuzufügen, musst du zuerst das Kalender-Modul aktivieren.',
    'Include Organizer and Participant Info in Exports' => 'Organisatoren- und Teilnehmerinformationen in Exporte einschließen',
    'Interested' => 'Interessiert',
    'Invalid date or time format!' => 'Datumsformat ungültig!',
    'Invalid day of month given' => 'Ungültiger Tag',
    'Invalid event type id selected.' => 'Ungültige Kategorie-ID ausgewählt',
    'Invalid frequency given' => 'Ungültige Wiederholungshäufigkeit',
    'Invalid interval given' => 'Ungültiges Intervall',
    'Invalid week day selection' => 'Ungültiger Wochentag',
    'Invite' => 'Einladen',
    'Invited: {users}' => 'Eingeladen: {users}',
    'JWT Key' => 'JWT Key',
    'JWT Token Expiration' => 'Ablauf des JWT-Tokens',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => 'Leer lassen um alle Termine aufzulisten. Gib 0 ein, um ausschließlich die heutigen Termine anzuzeigen.',
    'List' => 'Liste',
    'Location' => 'Ort',
    'Manage entries' => 'Kalendereinträge verwalten',
    'Maximum number of participants' => 'Maximale Teilnehmerzahl',
    'Minute' => 'Minute',
    'Mode' => 'Teilnahme-Modus',
    'Monday' => 'Montag',
    'Month' => 'Monat',
    'Monthly on day {dayOfMonth}' => 'Monatlich am Tag {dayOfMonth}',
    'Monthly on the {position} {dayOfWeek}' => 'Monatlich am {position} {dayOfWeek}',
    'Months' => 'Monate',
    'Never' => 'Nie',
    'Next' => 'Weiter',
    'No new participants were added.' => 'Es wurden keine neuen Teilnehmer hinzugefügt.',
    'No new participants were invited.' => 'Es wurden keine neuen Teilnehmer eingeladen.',
    'No reminder' => 'Keine Erinnerung',
    'Notify participants about changes' => 'Teilnehmer über Änderungen informieren.',
    'On date' => 'Am Datum',
    'Participant removed.' => 'Teilnehmer entfernt.',
    'Participants' => 'Teilnehmer',
    'Participation Status' => 'Teilnahme-Status',
    'Please select new participants.' => 'Bitte wähle neue Teilnehmer.',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => 'Private Termine sind nur für Sie und Ihre Freunde sichtbar (wenn das Freundschaftssystem aktiviert ist).',
    'Profile Calendar' => 'Profilkalender',
    'Public' => 'Öffentlich',
    'Recurring' => 'Wiederkehrend',
    'Reopen Event' => 'Termin wieder öffnen',
    'Repeat every' => 'Wiederhole jeden',
    'Saturday' => 'Samstag',
    'Select calendar...' => 'Kalender auswählen…',
    'Select space...' => 'Space auswählen…',
    'Set reminder' => 'Erinnerung erstellen',
    'Show past events' => 'Zeige vergangene Termine',
    'Sorting' => 'Sortierung',
    'Start Date' => 'Startdatum',
    'Start Time' => 'Startzeit',
    'Status cannot be updated.' => 'Status kann nicht aktualisiert werden.',
    'Status updated.' => 'Status aktualisiert.',
    'Sunday' => 'Sonntag',
    'The event has already ended.' => 'Der Termin ist bereits beendet.',
    'This event does not support recurrent events' => 'Dieses Event unterstützt keine wiederkehrenden Termine',
    'Thursday' => 'Donnerstag',
    'Time Zone' => 'Zeitzone',
    'Title' => 'Titel',
    'Today' => 'Heute',
    'Tuesday' => 'Dienstag',
    'Upcoming {type}' => 'Anstehend {type}',
    'Upcoming {type}: {title}' => 'Anstehend {type}: {title}',
    'Use default reminder' => 'Voreinstellungen verwenden',
    'User birthdays' => 'Benutzer Geburtstage',
    'Wednesday' => 'Mittwoch',
    'Week' => 'Woche',
    'Weeks' => 'Wochen',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => 'Wenn aktiviert, enthalten Kalenderexporte (ICS, iCal, CalDAV) die Namen und E-Mail-Adressen von Organisatoren und Teilnehmern. Deaktiviere diese Option, um diese Informationen auszuschließen.',
    'Year' => 'Jahr',
    'Years' => 'Jahre',
    'You cannot invite participants!' => 'Du kannst keine Teilnehmer einladen!',
    'You don\'t have permission to delete this event!' => 'Du hast nicht die Berechtigung diesen Termin zu löschen!',
    'You have an <strong>{type}</strong> coming up' => '<strong>{type}</strong> steht an',
    'You have an <strong>{type}</strong> coming up: {title}' => '<strong>{type}</strong> steht an: {title}',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => 'Du hast dich für die Veranstaltung "{contentTitle}" im {spaceName} angemeldet, die um {time} beginnt.',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => 'Du hast dich für die Veranstaltung "{contentTitle}" angemeldet, die um {time} beginnt.',
    'You have been registered for the event "{contentTitle}".' => 'Du hast dich für die Veranstaltung "{contentTitle}" angemeldet.',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => 'Deine eingestellten Erinnerungen für den Termin: <strong>\'{title}\'</strong>',
    'canceled' => 'Abgesagt',
    'disabled' => 'Deaktiviert',
    'first' => 'erst.',
    'forth' => 'viert.',
    'global' => 'Global',
    'iCal' => 'iCal',
    'in seconds. 0 for no JWT token expiration.' => 'In Sekunden. 0 bedeutet, dass das JWT-Token nicht abläuft.',
    'last' => 'zuletzt',
    'on weekdays' => 'an Wochentagen',
    'second' => 'zweit.',
    'third' => 'dritt.',
    '{displayName} Birthday' => '{displayName} Geburtstag',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} hat dich zum Event"{contentTitle}" im Space {spaceName}, beginnend um {time}, hinzugefügt.',
    '{displayName} added you to the event "{contentTitle}".' => '{displayName} hat dich zum Event "{contentTitle}" hinzugefügt.',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} hat dich zum Event "{contentTitle}" im Space {spaceName}, beginnend um {time}, eingeladen.',
    '{displayName} invited you to the event "{contentTitle}".' => '{displayName} hat dich zum Event "{contentTitle}" eingeladen.',
    '{name} Calendar' => '{name} Kalender',
    'Calendar event content ID' => '',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => '',
];

==> calendar-v1.8.3.zip: calendar/messages/de/base.php <==
<?php

return [
    '<strong>Add</strong> profile calendar' => 'Profilkalender <strong>erstellen</strong>',
    '<strong>Choose</strong> target calendar' => 'Zielkalender <strong>wählen</strong>',
    '<strong>Reminder</strong> settings' => '<strong>Erinnerungs</strong>einstellungen',
    'Add all Space members with status {status}' => 'Alle Space-Mitglieder hinzufügen und als {status} markieren',
    'Add participants...' => 'Teilnehmer hinzufügen und markieren als ...',
    'Added: {users}' => 'Hinzugefügt: {users}',
    'Additional Information for participants' => 'Weitere Teilnahme-Infos',
    'Adds a calendar for private or public events to your profile and main menu.' => 'Fügt deinem Profil und Hauptmenü einen Kalender für private und öffentliche Termine hinzu.',
    'Adds an event calendar to this space.' => 'Fügt diesem Space einen Kalender hinzu.',
    'After (occurrences)' => 'Nach (Anzahl)',
    'All Day' => 'Ganztägig',
    'Allow option \'Decline\'' => 'Erlaube Option "Ablehnen"',
    'Allow option \'Undecided\'' => 'Erlaube Option "Vielleicht"',
    'Allows the user to create new calendar entries' => 'Erlaubt dem Benutzer, neue Kalendereinträge zu erstellen.',
    'Allows the user to edit/delete existing calendar entries' => 'Erlaubt dem Benutzer, bestehende Kalendereinträge zu bearbeiten/löschen.',
    'Attending' => 'Du nimmst teil',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => 'Bevor ein Zielkalender ausgewählt werden kann, muss das Modul in mindestens einem Space aktiviert sein.',
    'Birthday' => 'Geburtstag',
    'CalDAV' => 'CalDAV',
    'Calendar' => 'Kalender',
    'Calendar event' => 'Kalender Termin',
    'Calendar events' => 'Kalender Termine',
    'Cancel Event' => 'Termin absagen',
    'Cannot remove the participant!' => 'Teilnehmer konnte nicht entfernt werden!',
    'Create entry' => 'Kalendereinträge erstellen',
    'Custom reminder' => 'Individuelle Erinnerung',
    'Day' => 'Tag',
    'Days' => 'Tage',
    'Default reminder settings' => 'Standardmäßige Einstellungen',
    'Delete all events' => 'Alle Termine löschen',
    'Deleted' => 'Gelöscht',
    'Description' => 'Beschreibung',
    'Display events within the next X days' => 'Zeige die Termine innerhalb der nächsten X Tage',
    'Do you want to install this module on your profile?' => 'Willst du dieses Modul für dein eigenes Profil installieren?',
    'Download ICS' => 'Herunterladen als ICS-Datei',
    'Edit' => 'Bearbeiten',
    'Edit Event' => 'Termin bearbeiten',
    'Edit all events' => 'Alle Termine bearbeiten',
    'Edit this and following events' => 'Diesen und alle folgenden Termine bearbeiten',
    'Edit this event' => 'Diesen Termin ändern',
    'Email' => 'E-Mail-Adresse',
    'Enable' => 'Aktivieren',
    'Enable Reminder' => 'Erinnerung einrichten',
    'End' => 'Ende',
    'End Date' => 'Enddatum',
    'End Time' => 'Endzeit',
    'End time must be after start time!' => 'Die Endzeit muss nach der Startzeit sein!',
    'Event' => 'Termin',
    'Event Type' => 'Event Kategorie',
    'Event Types' => 'Event Kategorien',
    'Event could not be deleted!' => 'Veranstaltung konnte nicht gelöscht werden!',
    'Event has been be deleted!' => 'Veranstaltung wurde gelöscht!',
    'Event not found!' => 'Termin nicht gefunden!',
    'Export as {type}' => 'Exportiere als {type}',
    'Files' => 'Dateien',
    'Filter by types' => 'Filtern nach Kategorie',
    'Friday' => 'Freitag',
    'From Newest to Oldest' => 'Vom Neuesten zum Ältesten',
    'From Oldest to Newest' => 'Vom Ältesten zum Neuesten',
    'Here you can configure default settings for all calendar events.' => 'Hier können Sie Voreinstellungen für alle Kalendereinträge definieren.',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => 'Hier können Sie globale Voreinstellungen für die Erinnerungsfunktion definieren. Diese Einstellungen können von individuellen Einstellungen innerhalb der Spaces oder Profile überschrieben werden.',
    'Hour' => 'Stunde',
    'I\'m attending' => 'Ich nehme teil',
    'ID' => 'ID',
    'In order to add events to your profile, you have to enable the calendar module first.' => 'Um deinem Profil Termine hinzuzufügen, musst du zuerst das Kalender-Modul aktivieren.',
    'Include Organizer and Participant Info in Exports' => 'Organisatoren- und Teilnehmerinformationen in Exporte einschließen',
    'Interested' => 'Interessiert',
    'Invalid date or time format!' => 'Datumsformat ungültig!',
    'Invalid day of month given' => 'Ungültiger Tag',
    'Invalid event type id selected.' => 'Ungültige Kategorie-ID ausgewählt',
    'Invalid frequency given' => 'Ungültige Wiederholungshäufigkeit',
    'Invalid interval given' => 'Ungültiges Intervall',
    'Invalid week day selection' => 'Ungültiger Wochentag',
    'Invite' => 'Einladen',
    'Invited: {users}' => 'Eingeladen: {users}',
    'JWT Key' => 'JWT Key',
    'JWT Token Expiration' => 'Ablauf des JWT-Tokens',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => 'Leer lassen um alle Termine aufzulisten. Gib 0 ein, um ausschließlich die heutigen Termine anzuzeigen.',
    'List' => 'Liste',
    'Location' => 'Ort',
    'Manage entries' => 'Kalendereinträge verwalten',
    'Maximum number of participants' => 'Maximale Teilnehmerzahl',
    'Minute' => 'Minute',
    'Mode' => 'Teilnahme-Modus',
    'Monday' => 'Montag',
    'Month' => 'Monat',
    'Monthly on day {dayOfMonth}' => 'Monatlich am Tag {dayOfMonth}',
    'Monthly on the {position} {dayOfWeek}' => 'Monatlich am {position} {dayOfWeek}',
    'Months' => 'Monate',
    'Never' => 'Nie',
    'Next' => 'Weiter',
    'No new participants were added.' => 'Es wurden keine neuen Teilnehmer hinzugefügt.',
    'No new participants were invited.' => 'Es wurden keine neuen Teilnehmer eingeladen.',
    'No reminder' => 'Keine Erinnerung',
    'Notify participants about changes' => 'Teilnehmer über Änderungen informieren.',
    'On date' => 'Am Datum',
    'Participant removed.' => 'Teilnehmer entfernt.',
    'Participants' => 'Teilnehmer',
    'Participation Status' => 'Teilnahme-Status',
    'Please select new participants.' => 'Bitte wähle neue Teilnehmer.',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => 'Private Termine sind nur für Sie und Ihre Freunde sichtbar (wenn das Freundschaftssystem aktiviert ist).',
    'Profile Calendar' => 'Profilkalender',
    'Public' => 'Öffentlich',
    'Recurring' => 'Wiederkehrend',
    'Reopen Event' => 'Termin wieder öffnen',
    'Repeat every' => 'Wiederhole jeden',
    'Saturday' => 'Samstag',
    'Select calendar...' => 'Kalender auswählen…',
    'Select space...' => 'Space auswählen…',
    'Set reminder' => 'Erinnerung erstellen',
    'Show past events' => 'Zeige vergangene Termine',
    'Sorting' => 'Sortierung',
    'Start Date' => 'Startdatum',
    'Start Time' => 'Startzeit',
    'Status cannot be updated.' => 'Status kann nicht aktualisiert werden.',
    'Status updated.' => 'Status aktualisiert.',
    'Sunday' => 'Sonntag',
    'The event has already ended.' => 'Der Termin ist bereits beendet.',
    'This event does not support recurrent events' => 'Dieses Event unterstützt keine wiederkehrenden Termine',
    'Thursday' => 'Donnerstag',
    'Time Zone' => 'Zeitzone',
    'Title' => 'Titel',
    'Today' => 'Heute',
    'Tuesday' => 'Dienstag',
    'Upcoming {type}' => 'Anstehend {type}',
    'Upcoming {type}: {title}' => 'Anstehend {type}: {title}',
    'Use default reminder' => 'Voreinstellungen verwenden',
    'User birthdays' => 'Benutzer Geburtstage',
    'Wednesday' => 'Mittwoch',
    'Week' => 'Woche',
    'Weeks' => 'Wochen',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => 'Wenn aktiviert, enthalten Kalenderexporte (ICS, iCal, CalDAV) die Namen und E-Mail-Adressen von Organisatoren und Teilnehmern. Deaktiviere diese Option, um diese Informationen auszuschließen.',
    'Year' => 'Jahr',
    'Years' => 'Jahre',
    'You cannot invite participants!' => 'Du kannst keine Teilnehmer einladen!',
    'You don\'t have permission to delete this event!' => 'Du hast nicht die Berechtigung diesen Termin zu löschen!',
    'You have an <strong>{type}</strong> coming up' => '<strong>{type}</strong> steht an',
    'You have an <strong>{type}</strong> coming up: {title}' => '<strong>{type}</strong> steht an: {title}',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => 'Du hast dich für die Veranstaltung "{contentTitle}" im {spaceName} angemeldet, die um {time} beginnt.',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => 'Du hast dich für die Veranstaltung "{contentTitle}" angemeldet, die um {time} beginnt.',
    'You have been registered for the event "{contentTitle}".' => 'Du hast dich für die Veranstaltung "{contentTitle}" angemeldet.',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => 'Deine eingestellten Erinnerungen für den Termin: <strong>\'{title}\'</strong>',
    'canceled' => 'Abgesagt',
    'disabled' => 'Deaktiviert',
    'first' => 'erst.',
    'forth' => 'viert.',
    'global' => 'Global',
    'iCal' => 'iCal',
    'in seconds. 0 for no JWT token expiration.' => 'In Sekunden. 0 bedeutet, dass das JWT-Token nicht abläuft.',
    'last' => 'zuletzt',
    'on weekdays' => 'an Wochentagen',
    'second' => 'zweit.',
    'third' => 'dritt.',
    '{displayName} Birthday' => '{displayName} Geburtstag',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} hat dich zum Event"{contentTitle}" im Space {spaceName}, beginnend um {time}, hinzugefügt.',
    '{displayName} added you to the event "{contentTitle}".' => '{displayName} hat dich zum Event "{contentTitle}" hinzugefügt.',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} hat dich zum Event "{contentTitle}" im Space {spaceName}, beginnend um {time}, eingeladen.',
    '{displayName} invited you to the event "{contentTitle}".' => '{displayName} hat dich zum Event "{contentTitle}" eingeladen.',
    '{name} Calendar' => '{name} Kalender',
    'Calendar event content ID' => '',
    'Filter' => '',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
    <strong>Set reminder</strong> link.' => '',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => '',
];
